import os
import cPickle

# Make package globals
this_dir, this_file = os.path.split(__file__)
path = os.path.join(this_dir, 'data', 'icd2desc.p')
icd2desc = cPickle.load(open(path, 'rb'))
path = os.path.join(this_dir, 'data', 'icd2ccs.p')
icd2ccs = cPickle.load(open(path, 'rb'))
path = os.path.join(this_dir, 'data', 'ccs2icd.p')
ccs2icd = cPickle.load(open(path, 'rb'))
path = os.path.join(this_dir, 'data', 'ccs2desc.p')
ccs2desc = cPickle.load(open(path, 'rb'))




from codes import icd2desc

def find_codes(search_word):
    codes = {}
    for code, desc in icd2desc.iteritems():
        if search_word in desc.lower():
            codes[code] = desc
    return codes


if __name__ == '__main__':
    print find_codes('fish')



from distutils.core import setup

setup(
    name='Health',
    version='1.2',
    author='Sean Wade',
    author_email='seanwademail@gmail.com',
    packages=['health'],
    license='Apache-2.0',
    description='Healthcare research tools',
    package_data={
        'health': ['data/*.p'],
        },
    include_package_data=True,
)
